/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\
 * This is GNU GO, a Go program. Contact gnugo@gnu.org, or see   *
 * http://www.gnu.org/software/gnugo/ for more information.      *
 *                                                               *
 * Copyright 1999 and 2000 by the Free Software Foundation.      *
 *                                                               *
 * This program is free software; you can redistribute it and/or *
 * modify it under the terms of the GNU General Public License   *
 * as published by the Free Software Foundation - version 2.     *
 *                                                               *
 * This program is distributed in the hope that it will be       *
 * useful, but WITHOUT ANY WARRANTY; without even the implied    *
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR       *
 * PURPOSE.  See the GNU General Public License in file COPYING  *
 * for more details.                                             *
 *                                                               *
 * You should have received a copy of the GNU General Public     *
 * License along with this program; if not, write to the Free    *
 * Software Foundation, Inc., 59 Temple Place - Suite 330,       *
 * Boston, MA 02111, USA                                         *
\* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */





/*-------------------------------------------------------------------------
 * interface.h
 * 	This file contains all headers for interfaces
 *-------------------------------------------------------------------------*/

#ifndef _PLAY_INTERFACE_H
#define _PLAY_INTERFACE_H

#include "gnugo.h"
#include "ttsgf.h"

enum testmode {UNKNOWN_TESTMODE=0, MOVE_ONLY, ANNOTATION_ONLY, BOTH, GAME};

struct SGFNode_t;  /* forward decl to keep gcc happy */

void play_ascii(char * filename, char * until);
void play_ascii_emacs(char * filename, char * until);
void play_gmp(int boardsize);
void play_solo(int boardsize, int benchmark);
void play_test(SGFNode *, enum testmode);

int load_sgf_file(SGFNode *, Position *position, const char *untilstr);
void load_sgf_header(SGFNode *);
void load_and_analyze_sgf_file(SGFNode *, Position *position,
			       const char *untilstr, int benchmark);
void load_and_score_sgf_file(SGFNode *, Position *position,
			     const char *untilstr);


/* ---------------------------------------------------------------
 * These functions deal with the game information structure
 * --------------------------------------------------------------- */
void init_ginfo(void);
void print_ginfo(void);
int get_boardsize(void);
int set_boardsize(int);
int get_handicap(void);
int set_handicap(int);
float get_komi(void);
void set_komi(float);
int get_movenumber(void);
int set_movenumber(int);
int inc_movenumber(void);
int dec_movenumber(void);
int get_tomove(void);
int set_tomove(int);
int switch_tomove(void);
int get_computer_player(void);
void set_computer_player(int);
int is_computer_player(int);
int switch_computer_player(void);
int get_seed(void);
int set_seed(int);
const char * get_outfile(void);
int set_outfile(const char *);


/* ---------------------------------------------------------------
 * These functions deal with move manipulation
 * --------------------------------------------------------------- */
int get_move(Position *, int *, int *, int);
int get_test_move(Position *, int *, int *, int);
int put_move(Position *, int, int, int);
int put_stone(Position *, int, int, int);


/* ---------------------------------------------------------------
 * These functions deal with the game option structure
 * --------------------------------------------------------------- */
void init_gopt(void);
int get_opt_quiet(void);
void set_opt_quiet(int);
int get_opt_display_board(void);
void set_opt_display_board(int);



#endif


/*
 * Local Variables:
 * tab-width: 8
 * c-basic-offset: 2
 * End:
 */
